==> dokuwiki-2017.02.19b.tgz: dokuwiki/lib/plugins/extension/lang/zh/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Cupen <Cupenoruler@foxmail.com>
 * @author xiqingongzi <Xiqingongzi@Gmail.com>
 * @author qinghao <qingxianhao@gmail.com>
 * @author lainme <lainme993@gmail.com>
 * @author Errol <errol@hotmail.com>
 * @author phy25 <git@phy25.com>
 */
$lang['menu']                  = '扩展管理器';
$lang['tab_plugins']           = '安装插件';
$lang['tab_templates']         = '安装模板';
$lang['tab_search']            = '搜索和安装';
$lang['tab_install']           = '手动安装';
$lang['notimplemented']        = '未实现的特性';
$lang['notinstalled']          = '该扩展未安装';
$lang['alreadyenabled']        = '该扩展已激活';
$lang['alreadydisabled']       = '该扩展已关闭';
$lang['pluginlistsaveerror']   = '保存插件列表时碰到个错误';
$lang['unknownauthor']         = '未知作者';
$lang['unknownversion']        = '未知版本';
$lang['btn_info']              = '查看更多信息';
$lang['btn_update']            = '更新';
$lang['btn_uninstall']         = '卸载';
$lang['btn_enable']            = '激活';
$lang['btn_disable']           = '关闭';
$lang['btn_install']           = '安装';
$lang['btn_reinstall']         = '重新安装';
$lang['js']['reallydel']       = '确定卸载这个扩展么？';
$lang['js']['display_viewoptions'] = '查看选项:';
$lang['js']['display_enabled'] = '启用';
$lang['js']['display_disabled'] = '禁用';
$lang['js']['display_updatable'] = '可更新';
$lang['search_for']            = '搜索扩展';
$lang['search']                = '搜索';
$lang['extensionby']           = '<strong>%s</strong> by %s';
$lang['screenshot']            = '%s 的截图';
$lang['popularity']            = '人气: %s%%';
$lang['homepage_link']         = '文档';
$lang['bugs_features']         = '错误';
$lang['tags']                  = '标签：';
$lang['author_hint']           = '搜索这个作者的插件';
$lang['installed']             = '已安装的：';
$lang['downloadurl']           = '下载地址：';
$lang['repository']            = '版本库：';
$lang['unknown']               = '<em>未知的</em>';
$lang['installed_version']     = '已安装版本：';
$lang['install_date']          = '您的最后一次升级：';
$lang['available_version']     = '可用版本：';
$lang['compatible']            = '兼容于：';
$lang['depends']               = '依赖于：';
$lang['similar']               = '相似于：';
$lang['conflicts']             = '冲突于：';
$lang['donate']                = '喜欢？';
$lang['donate_action']         = '捐给作者一杯咖啡钱！';
$lang['repo_retry']            = '重试';
$lang['provides']              = '提供：';
$lang['status']                = '现状：';
$lang['status_installed']      = '已安装的';
$lang['status_not_installed']  = '未安装';
$lang['status_protected']      = '受保护';
$lang['status_enabled']        = '启用';
$lang['status_disabled']       = '禁用';
$lang['status_unmodifiable']   = '不可修改';
$lang['status_plugin']         = '插件';
$lang['status_template']       = '模板';
$lang['status_bundled']        = '内建';
$lang['msg_enabled']           = '插件 %s 已启用';
$lang['msg_disabled']          = '插件 %s 已禁用';
$lang['msg_delete_success']    = '插件已经卸载';
$lang['msg_delete_failed']     = '卸载扩展 %s 失败';
$lang['msg_template_install_success'] = '模板 %s 安装成功';
$lang['msg_template_update_success'] = '模板 %s 更新成功';
$lang['msg_plugin_install_success'] = '插件 %s 安装成功';
$lang['msg_plugin_update_success'] = '插件 %s 更新成功';
$lang['msg_upload_failed']     = '上传文件失败';
$lang['missing_dependency']    = '<strong>缺少或者被禁用依赖：</strong> %s';
$lang['security_issue']        = '<strong>安全问题：</strong> %s';
$lang['security_warning']      = '<strong>安全警告：</strong> %s';
$lang['update_available']      = '<strong>更新：</strong>新版本 %s 已经可用。';
$lang['wrong_folder']          = '<strong>插件安装不正确：</strong>重命名插件目录 "%s" 为 "%s"。';
$lang['url_change']            = '<strong>URL已改变：</strong>自上次下载以来的下载 URL 已经改变。请在更新扩展前检查新 URL 是否有效。<br />新的：%s<br />旧的：%s';
$lang['error_badurl']          = 'URL 应当以 http 或者 https 作为开头';
$lang['error_dircreate']       = '无法创建用于保存下载的临时文件夹';
$lang['error_download']        = '无法下载文件：%s';
$lang['error_decompress']      = '无法解压下载的文件。这可能是由于文件损坏，在这种情况下您可以重试。这也可能是由于压缩格式是未知的，在这种情况下您需要手动下载并且安装。';
$lang['error_findfolder']      = '无法识别扩展目录，您需要手动下载和安装';
$lang['error_copy']            = '在尝试安装文件到目录 <em>%s</em> 时出现文件复制错误：磁盘可能已满或者文件访问权限不正确。这可能导致插件被部分安装并使您的维基处在不稳定状态';
$lang['noperms']               = '扩展目录不可写';
$lang['notplperms']            = '模板目录不可写';
$lang['nopluginperms']         = '插件目录不可写';
$lang['git']                   = '这个扩展是通过 Git 安装的，您可能不想在这里升级它';
$lang['auth']                  = '这个认证插件没有在配置中启用，请考虑禁用它。';
$lang['install_url']           = '从 URL 安装：';
$lang['install_upload']        = '上传扩展：';
$lang['repo_error']            = '无法连接到插件仓库。请确定您的服务器可以连接 www.dokuwiki.org 并检查您的代理设置。';
$lang['nossl']                 = '您的 PHP 似乎不支持 SSL。很多 DokuWiki 扩展将无法下载。';

==> dokuwiki-2023.04.04p2.tgz: dokuwiki/lib/plugins/extension/lang/zh/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Xin <chenxin1034@gmail.com>
 * @author lempel <riverlempel@hotmail.com>
 * @author Cupen <Cupenoruler@foxmail.com>
 * @author xiqingongzi <Xiqingongzi@Gmail.com>
 * @author qinghao <qingxianhao@gmail.com>
 * @author lainme <lainme993@gmail.com>
 * @author Errol <errol@hotmail.com>
 * @author phy25 <git@phy25.com>
 * @author fengyqf <fengyqf@gmail.com>
 */
$lang['menu']                  = '扩展管理器';
$lang['tab_plugins']           = '现有插件';
$lang['tab_templates']         = '现有模板';
$lang['tab_search']            = '搜索安装';
$lang['tab_install']           = '手动安装';
$lang['notimplemented']        = '未实现的特性';
$lang['notinstalled']          = '该扩展未安装';
$lang['alreadyenabled']        = '该扩展已激活';
$lang['alreadydisabled']       = '该扩展已关闭';
$lang['pluginlistsaveerror']   = '保存插件列表时出现错误';
$lang['unknownauthor']         = '未知作者';
$lang['unknownversion']        = '未知版本';
$lang['btn_info']              = '查看更多信息';
$lang['btn_update']            = '更新';
$lang['btn_uninstall']         = '卸载';
$lang['btn_enable']            = '激活';
$lang['btn_disable']           = '关闭';
$lang['btn_install']           = '安装';
$lang['btn_reinstall']         = '重新安装';
$lang['js']['reallydel']       = '确定卸载这个扩展吗？';
$lang['js']['display_viewoptions'] = '查看选项：';
$lang['js']['display_enabled'] = '启用';
$lang['js']['display_disabled'] = '禁用';
$lang['js']['display_updatable'] = '可更新';
$lang['search_for']            = '搜索扩展';
$lang['search']                = '搜索';
$lang['extensionby']           = '<strong>%s</strong> by %s';
$lang['screenshot']            = '%s 的截图';
$lang['popularity']            = '人气: %s%%';
$lang['homepage_link']         = '文档';
$lang['bugs_features']         = '错误';
$lang['tags']                  = '标签：';
$lang['author_hint']           = '搜索这个作者的扩展';
$lang['installed']             = '已安装的：';
$lang['downloadurl']           = '下载地址：';
$lang['repository']            = '版本库：';
$lang['unknown']               = '<em>未知的</em>';
$lang['installed_version']     = '已安装版本：';
$lang['install_date']          = '您的最后一次升级：';
$lang['available_version']     = '可用版本：';
$lang['compatible']            = '兼容于：';
$lang['depends']               = '依赖于：';
$lang['similar']               = '相似于：';
$lang['conflicts']             = '冲突于：';
$lang['donate']                = '喜欢吗？';
$lang['donate_action']         = '赞赏作者一杯咖啡的钱！';
$lang['repo_retry']            = '重试';
$lang['provides']              = '提供：';
$lang['status']                = '状态：';
$lang['status_installed']      = '已安装的';
$lang['status_not_installed']  = '未安装';
$lang['status_protected']      = '受保护';
$lang['status_enabled']        = '启用';
$lang['status_disabled']       = '禁用';
$lang['status_unmodifiable']   = '不可修改';
$lang['status_plugin']         = '插件';
$lang['status_template']       = '模板';
$lang['status_bundled']        = '内建';
$lang['msg_enabled']           = '插件 %s 已启用';
$lang['msg_disabled']          = '插件 %s 已禁用';
$lang['msg_delete_success']    = '%s 扩展没有安装';
$lang['msg_delete_failed']     = '卸载扩展 %s 失败';
$lang['msg_template_install_success'] = '模板 %s 安装成功';
$lang['msg_template_update_success'] = '模板 %s 更新成功';
$lang['msg_plugin_install_success'] = '插件 %s 安装成功';
$lang['msg_plugin_update_success'] = '插件 %s 更新成功';
$lang['msg_upload_failed']     = '上传文件失败';
$lang['msg_nooverwrite']       = '扩展名 %s 已存在，因此不会被覆盖；要覆盖，请选中覆盖选项。';
$lang['missing_dependency']    = '<strong>缺少或者被禁用的依赖：</strong> %s';
$lang['security_issue']        = '<strong>安全问题：</strong> %s';
$lang['security_warning']      = '<strong>安全警告：</strong> %s';
$lang['update_available']      = '<strong>更新：</strong>新版本 %s 已经可用。';
$lang['wrong_folder']          = '<strong>扩展安装错误：</strong>请将扩展目录 "%s" 重命名为 "%s"。';
$lang['url_change']            = '<strong>URL 已改变：</strong>自上次下载以来的下载 URL 已经改变。请在更新扩展前检查新 URL 是否有效。<br />新的：%s<br />旧的：%s';
$lang['error_badurl']          = 'URL 应当以 http 或者 https 作为开头';
$lang['error_dircreate']       = '无法创建用于保存下载的临时文件夹';
$lang['error_download']        = '无法下载文件：%s';
$lang['error_decompress']      = '无法解压下载的文件。这可能是由于文件损坏，在这种情况下您可以重试。这也可能是由于压缩格式是未知的，在这种情况下您需要手动下载并且安装。';
$lang['error_findfolder']      = '无法识别扩展目录，您需要手动下载和安装';
$lang['error_copy']            = '在尝试安装文件到目录 <em>%s</em> 时出现文件复制错误：可能磁盘已满或文件权限不正确。这可能导致扩展安装不完整，并使您的维基处在不稳定状态';
$lang['noperms']               = '扩展目录不可写';
$lang['notplperms']            = '模板目录不可写';
$lang['nopluginperms']         = '插件目录不可写';
$lang['git']                   = '这个扩展是通过 Git 安装的，您可能不想在这里升级它';
$lang['auth']                  = '这个认证插件没有在配置中启用，请考虑禁用它。';
$lang['install_url']           = '从 URL 安装：';
$lang['install_upload']        = '上传扩展：';
$lang['repo_error']            = '无法连接到扩展库。请确定您的服务器可以连接 www.dokuwiki.org 并检查您的代理设置。';
$lang['nossl']                 = '您的 PHP 似乎不支持 SSL，这将导致无法下载多数 DokuWiki 扩展。';
